@@ -1,3 +1,24 @@
+/*
+ * Argus Software.  Common include files. fddi.h
+ * Copyright (c) 2000-2008 QoSient, LLC
+ * All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ */
+
 /*
  * Copyright (c) 1992, 1993, 1994
  *	The Regents of the University of California.  All rights reserved.
@@ -18,9 +39,17 @@
  * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
  * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
- * @(#) $Header: /usr/users/poepping/src/argus/argus-1.5/include/RCS/fddi.h,v 1.1 1995/02/08 21:06:41 poepping Exp $ (LBL)
  */
 
+/* 
+ * $Id: $
+ * $DateTime: $
+ * $Change: $
+ */
+
+#if !defined(fddi_h)
+#define fddi_h
+
 /*
  * Based on Ultrix if_fddi.h
  */
@@ -74,3 +103,4 @@ struct fddi_header {
 
 #define	FDDIFC_CLFF		0xF0		/* Class/Length/Format bits */
 #define	FDDIFC_ZZZZ		0x0F		/* Control bits */
+#endif
